import logging
from atgateway.app.sensing_mgr.model_dev_base import ModelDevBase
from atgateway.app.sensing_mgr.const import Const
from atgateway.app.sensing_mgr.io.led_device import LedDevice
from .reporters.count_reporter import CountReporter

class ModelDevA6EBase(ModelDevBase):
    def __init__(self, modelConfig, cloud_config, send_cloud):
        super().__init__(modelConfig, send_cloud)
        self._count_reporter = None
        self._reporters = {}
        self._model_config = modelConfig
        self._cloud_config = cloud_config
        self._logging = logging.getLogger(Const.LOGGER_NAME)

    def on_recv_data(self, data):
        if data is None:
            self._logging.info("data from cloud is empty.")
            return False

        if self._cloud_config:
            self._logging.info("update config from cloud.")
            self.update_reporter(self._model_config, data)
        else:
            self._logging.info("config don't update from cloud.")

        return self.exec_command(self._model_config, data)

    def update_reporter(self, config, data):
        update_list = config.update_config(data)

        if not update_list:
            return

    def exec_command(self, config, data):
        ret = True
        for section, conf in data.items():
            index = section.find('_command')
            section = section[:index]

            if conf == "":
                continue

            elif section == "led":
                key = "state"

                if key in conf.keys():
                    self._logging.info(f"led is {key}:{conf[key]}")

                    if conf[key] == "on":
                        with LedDevice.get("app") as led:
                            led.on_or_off(True)
                    elif conf[key] == 'off':
                        with LedDevice.get("app") as led:
                            led.on_or_off(False)
                    else:
                        ret = False
                        self._logging.error(
                            "led_command valid value is on or off.")
                else:
                    ret = False
                    self._logging.error("led_command don't have [state]")
        return ret

    def send_interval(self, config):
        conf = config.get_default_conf()
        return conf.get(config.SEND_INTERVAL)

    def _make_active_reporters(self, config, report_queue, report_repository):
        reporters = []
        return reporters

    def _make_reporters(self, config):
        # hide super()'s CpuTempReporter
        reporters = []

        # CountReporter
        countReporter = CountReporter(
            start=True,
            interval=5
            )
        countReporter.set_interval(5)
        reporters.append(countReporter)
        self._count_reporter = countReporter
        return reporters

    def _make_sensing_manager(self, config):
        self._sensing_mgr = None
        return self._sensing_mgr

#
# End of File
#
